==> sal-organization-2.1.9-20161207.110805-28-sources.jar: com/baijia/tianxiao/sal/organization/org/service/TxCascadeCredentialService.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2016 All Rights Reserved.
 */
package com.baijia.tianxiao.sal.organization.org.service;

import com.baijia.tianxiao.dal.org.po.TXCascadeCredential;
import com.baijia.tianxiao.sal.organization.constant.CascadeSearchSource;
import com.baijia.tianxiao.sal.organization.org.dto.AccountSelectionDto;
import com.baijia.tianxiao.sal.organization.org.dto.TxCascadeCredentialDto;
import com.baijia.tianxiao.sal.organization.org.dto.TxCascadeCredentialSelectionDto;
import com.baijia.tianxiao.sal.organization.todo.dto.HeadTeacherRespDto;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;

import java.util.List;
import java.util.Map;

public interface TxCascadeCredentialService {

    Map<Long, String> getByTxCasCadeIds(Long orgId);

    TxCascadeCredentialDto getByTxCasCade(Long orgId, Integer cascadeId);

    List<TxCascadeCredentialDto> getTxCascadeCredentialList(Long orgId);

    boolean isShowMobile(Long orgId, Integer cascadeId);

    List<TxCascadeCredentialDto> getTxCascadeCredentialList(Long orgId, Integer cascadeId);

    List<TxCascadeCredentialSelectionDto> getTxCascadeCredentialList(Integer orgId, Long cascadeId, CascadeSearchSource source, AccountSelectionDto dto);

    public void setAvatar(Long orgId, Integer cascadeId, Long storageId, String avatar);

    /**
     * 筛选班级的班主任
     *
     * @param orgId：机构id
     * @param key：查询字符串
     * @param courseId：班级id
     * @return
     */
    List<HeadTeacherRespDto> listPcHeadTeacher(Long orgId, String key, Long courseId, PageDto pageDto);

    public TXCascadeCredential getByMobile(String mobile);

    public TXCascadeCredential modifyPassword(Integer id, String password);

}

==> sal-organization-2.25.0-20170531.073034-87-sources.jar: com/baijia/tianxiao/sal/organization/org/service/TxCascadeCredentialService.java <==
/**
 * Baijiahulian.com Inc. Copyright (c) 2014-2016 All Rights Reserved.
 */
package com.baijia.tianxiao.sal.organization.org.service;

import com.baijia.tianxiao.dal.org.po.TXCascadeCredential;
import com.baijia.tianxiao.sal.organization.constant.CascadeSearchSource;
import com.baijia.tianxiao.sal.organization.org.dto.AccountSelectionDto;
import com.baijia.tianxiao.sal.organization.org.dto.TxCascadeCredentialDto;
import com.baijia.tianxiao.sal.organization.org.dto.TxCascadeCredentialSelectionDto;
import com.baijia.tianxiao.sal.organization.todo.dto.HeadTeacherRespDto;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;

import java.util.Collection;
import java.util.List;
import java.util.Map;

public interface TxCascadeCredentialService {

    Map<Long, String> getByTxCasCadeIds(Long orgId);

    Map<Long, String> getByTxCasCadeIdWithDelete(Long orgId);

    TxCascadeCredentialDto getByTxCasCade(Long orgId, Integer cascadeId);

    List<TxCascadeCredentialDto> getTxCascadeCredentialList(Long orgId);

    boolean isShowMobile(Long orgId, Integer cascadeId);

    List<TxCascadeCredentialDto> getTxCascadeCredentialList(Long orgId, Integer cascadeId);

    List<TxCascadeCredentialSelectionDto> getTxCascadeCredentialList(Integer orgId, Long cascadeId, CascadeSearchSource source, AccountSelectionDto dto);

    public void setAvatar(Long orgId, Integer cascadeId, Long storageId, String avatar);

    /**
     * 筛选班级的班主任
     *
     * @param orgId：机构id
     * @param key：查询字符串
     * @param courseId：班级id
     * @return
     */
    List<HeadTeacherRespDto> listPcHeadTeacher(Long orgId, String key, Long courseId, PageDto pageDto);

    public TXCascadeCredential getByMobile(String mobile);

    public TXCascadeCredential modifyPassword(Integer id, String password);

    /**
     * 通过子账号id获取老师名称
     * @param cascadeIdList
     * @return
     */
    Map<Integer, String> getNameMapByAccountIds(Collection<Integer> cascadeIdCollection);
}
